/// <reference types="react" />
import * as React from "react";
export interface IDialogProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * Called before the default onKeyDown handlers are invoked.
     * @returns true if the key down event was handled and further key down events should not be handled
     */
    onKeyDown?: (event: React.KeyboardEvent<HTMLDivElement>) => boolean;
    /**
     * Executed whenever the user presses Escape or clicks the background
     */
    onBackgroundClick?: (event: React.MouseEvent<HTMLDivElement> | React.KeyboardEvent<HTMLDivElement>) => void;
    /**
     * If the base styles should be disabled (though if the base styles don't work for you, we'd love to know why!)
     */
    isBaseStylesDisabled?: boolean;
    /**
     * If the dialog is currently visible or not. The dialog component should always be mounted (so that animations work).
     * If you dismount the component before the animation finishes, the exit animation will likely look like it has not run.
     */
    isVisible: boolean;
}
export interface IDialogState {
    previousElementBeforeOpen: Element;
}
export declare class Dialog extends React.Component<IDialogProps, IDialogState> {
    private dialogRef;
    componentDidMount(): void;
    componentDidUpdate(oldProps: IDialogProps): void;
    render(): JSX.Element;
    protected onSetDialogRef: (ref: HTMLDivElement) => void;
    private onAnimationEnd;
    private onTransitionEnd;
    private onKeyDown;
    private onDialogClick;
    private onBackgroundClick;
    private handleEscapeClick(event);
    private handleTabClick(event);
    private setFocusIfVisible();
}
