"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var tabbable = require("tabbable");
var ts_keycode_enum_1 = require("ts-keycode-enum");
var Dialog = /** @class */ (function (_super) {
    tslib_1.__extends(Dialog, _super);
    function Dialog() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onSetDialogRef = function (ref) {
            _this.dialogRef = ref;
        };
        _this.onAnimationEnd = function (event) {
            if (_this.props.onAnimationEnd != null) {
                _this.props.onAnimationEnd(event);
                if (event.isDefaultPrevented()) {
                    return;
                }
            }
            _this.setFocusIfVisible();
        };
        _this.onTransitionEnd = function (event) {
            if (_this.props.onTransitionEnd != null) {
                _this.props.onTransitionEnd(event);
                if (event.isDefaultPrevented()) {
                    return;
                }
            }
            _this.setFocusIfVisible();
        };
        _this.onKeyDown = function (event) {
            if (_this.props.onKeyDown != null && _this.props.onKeyDown(event)) {
                return;
            }
            if (_this.handleEscapeClick(event)) {
                return;
            }
            if (_this.handleTabClick(event)) {
                return;
            }
        };
        _this.onDialogClick = function (event) {
            // event.preventDefault();
            event.stopPropagation();
        };
        _this.onBackgroundClick = function (event) {
            if (_this.props.onBackgroundClick) {
                _this.props.onBackgroundClick(event);
            }
        };
        return _this;
    }
    Dialog.prototype.componentDidMount = function () {
        if (this.props.isVisible === true) {
            this.setState({
                previousElementBeforeOpen: document.activeElement
            });
            this.dialogRef.focus();
        }
    };
    Dialog.prototype.componentDidUpdate = function (oldProps) {
        if (this.props.isVisible === true &&
            this.props.isVisible !== oldProps.isVisible) {
            // The dialog is going from not visible to visible
            this.dialogRef.scrollTop = 0;
            this.setState({
                previousElementBeforeOpen: document.activeElement
            });
            this.dialogRef.focus();
        }
        else if (this.props.isVisible === false &&
            this.props.isVisible !== oldProps.isVisible) {
            // The dialog is going from visible to not visible
            var htmlElement = this.state.previousElementBeforeOpen;
            if (htmlElement != null && htmlElement.focus != null) {
                htmlElement.focus();
            }
        }
    };
    Dialog.prototype.render = function () {
        var _a = this.props, isBaseStylesDisabled = _a.isBaseStylesDisabled, onBackgroundClick = _a.onBackgroundClick, isVisible = _a.isVisible, className = _a.className, htmlProps = tslib_1.__rest(_a, ["isBaseStylesDisabled", "onBackgroundClick", "isVisible", "className"]);
        var classNameArray = [];
        if (isBaseStylesDisabled !== true) {
            classNameArray.push("sci-react-dialog");
        }
        if (className != null) {
            classNameArray.push(className);
        }
        if (this.props.isVisible) {
            classNameArray.push("visible");
        }
        return (React.createElement("div", tslib_1.__assign({}, htmlProps, { className: classNameArray.join(" "), onAnimationEnd: this.onAnimationEnd, onTransitionEnd: this.onTransitionEnd }),
            React.createElement("div", { className: "overlay", onClick: this.onBackgroundClick },
                React.createElement("div", { ref: this.onSetDialogRef, role: "dialog", tabIndex: 1, className: "dialog", onClick: this.onDialogClick, onKeyDown: this.onKeyDown }, this.props.children))));
    };
    Dialog.prototype.handleEscapeClick = function (event) {
        if (event.isDefaultPrevented() || event.keyCode !== ts_keycode_enum_1.Key.Escape) {
            return false;
        }
        event.preventDefault();
        event.stopPropagation();
        this.onBackgroundClick(event);
        return true;
    };
    Dialog.prototype.handleTabClick = function (event) {
        if (event.isDefaultPrevented() || event.keyCode !== ts_keycode_enum_1.Key.Tab) {
            return false;
        }
        var tabbableElements = tabbable(this.dialogRef);
        var first = tabbableElements[0];
        var last = tabbableElements[tabbableElements.length - 1];
        if (first === undefined) {
            // This has no tabbable elements, set focus back on the dialog itself
            this.dialogRef.focus();
            event.preventDefault();
        }
        else if ((document.activeElement === this.dialogRef || document.activeElement === last) && !event.shiftKey) {
            first.focus();
            event.preventDefault();
        }
        else if ((document.activeElement === this.dialogRef || document.activeElement === first) && event.shiftKey) {
            last.focus();
            event.preventDefault();
        }
        return true;
    };
    // Needed when the root level element is animated
    Dialog.prototype.setFocusIfVisible = function () {
        if (this.props.isVisible === false) {
            // If we aren't visible, no need to set focus
            return;
        }
        if (this.dialogRef.contains(document.activeElement)) {
            // If we are focused on a subchild, no need to change focus
            return;
        }
        this.dialogRef.focus();
    };
    return Dialog;
}(React.Component));
exports.Dialog = Dialog;
//# sourceMappingURL=component.js.map